cosmpy.protos.tendermint.crypto package — cosmpy documentation

# cosmpy.protos.tendermint.crypto package

## Submodules

## cosmpy.protos.tendermint.crypto.keys_pb2 module

Generated protocol buffer code.

## cosmpy.protos.tendermint.crypto.keys_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.tendermint.crypto.proof_pb2 module

Generated protocol buffer code.

## cosmpy.protos.tendermint.crypto.proof_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## Module contents